# Bioplots: A Bioinformatics Toolkit
[![PyPI](https://img.shields.io/pypi/v/Bioplots?color=blue)](https://pypi.org/project/Bioplots/) ![PyPI - Format](https://img.shields.io/pypi/format/Bioplots?style=flat-square) ![PyPI - License](https://img.shields.io/pypi/l/Bioplots?color=red) [![Build Status](https://travis-ci.org/jingxinfu/Bioplots.svg?branch=master)](https://travis-ci.org/jingxinfu/Bioplots) [![PyPI - Downloads](https://img.shields.io/pypi/dm/Bioplots?color=green&label=pypi%20download&logoColor=green&style=flat-square)](https://pypi.org/project/Bioplots/) 

This package provides visualization functions that are frequently used by bioinformaticians. 

[Document](https://jingxinfu.github.io/Bioplots)

